#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_ANDNOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_ANDNOT_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/logical_andnot.hpp>

#endif
